@@ -1,10 +1,10 @@
 /* apply.c - apply the plan, performing the actual renames/copies
  *
- * Copyright (C) 2001, 2002, 2004, 2005, 2007 Oskar Liljeblad
+ * Copyright (C) 2001, 2002, 2004, 2005, 2007, 2008 Oskar Liljeblad
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -33,6 +33,8 @@
 #include "common/io-utils.h"
 #include "qcmd.h"
 
+char *force_command = NULL;
+
 static bool
 wait_child_and_check_status(const char *cmd)
 {
@@ -67,7 +69,9 @@ perform_command(FileSpec *spec)
         return false;
     }*/
 
-    if (strcmp(program, "qmv") == 0)
+    if (force_command != NULL)
+        command = force_command;
+    else if (strcmp(program, "qmv") == 0)
         command = "mv";
     else
         command = "cp";
